pm4py.algo.conformance.alignments package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.decomposed
   pm4py.algo.conformance.alignments.dfg
   pm4py.algo.conformance.alignments.edit_distance
   pm4py.algo.conformance.alignments.petri_net
   pm4py.algo.conformance.alignments.process_tree
   pm4py.algo.conformance.alignments.variants

Submodules
----------

pm4py.algo.conformance.alignments.algorithm module
--------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments
   :members:
   :undoc-members:
   :show-inheritance:
